==> org.eclipse.jubula.client.core.source_2.4.0.201408200918.jar: org/eclipse/jubula/client/core/businessprocess/ClientTestStrings.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.client.core.businessprocess;

/**
 * @author BREDEX GmbH
 * @created Feb 12, 2007
 */
public class ClientTestStrings {
    /** constant string */
    public static final String PROJECT = "project"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_VERSION = "version"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_VERSION_EX = "project_version"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_NAME = "project_name"; //$NON-NLS-1$
     /** object attribute */
    public static final String SERVER = "server"; //$NON-NLS-1$
    /** constant string */
    public static final String HOSTNAME = "hostname"; //$NON-NLS-1$
    /** object attribute */
    public static final String PORT = "port"; //$NON-NLS-1$
    /** constant string */
    public static final String PORT_NUMBER = "port_number"; //$NON-NLS-1$
    /** object attribute */
    public static final String DBURL = "dburl"; //$NON-NLS-1$
    /** constant string */
    public static final String DATABASE = "database"; //$NON-NLS-1$
    /** object attribute */
    public static final String DB_SCHEME = "dbscheme"; //$NON-NLS-1$
    /** object attribute */
    public static final String SCHEME = "scheme"; //$NON-NLS-1$
    /** object attribute */
    public static final String DB_USER = "dbuser"; //$NON-NLS-1$
    /** constant string */
    public static final String USER = "user"; //$NON-NLS-1$ 
    /** object attribute */
    public static final String DB_PW = "dbpw"; //$NON-NLS-1$
    /** constant string */
    public static final String PASSWORD = "password"; //$NON-NLS-1$
    /** object attribute */
    public static final String TESTSUITE = "testsuite"; //$NON-NLS-1$
    /** object attribute */
    public static final String TESTJOB = "testjob"; //$NON-NLS-1$
    /** object attribute */
    public static final String TIMEOUT = "timeout"; //$NON-NLS-1$
    /** object attribute */
    public static final String STARTSERVER = "startserver"; //$NON-NLS-1$
    
    /** object attribute */
    public static final String ENTRY = "entry"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUT_CONFIG = "autconfig"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUT_ID = "autid"; //$NON-NLS-1$
    /** object attribute */
    public static final String RESULTDIR = "resultdir"; //$NON-NLS-1$
    /** object attribute */
    public static final String LANGUAGE = "language"; //$NON-NLS-1$
    /** object attribute */
    public static final String DATA_DIR = "datadir"; //$NON-NLS-1$
    /** object attribute */
    public static final String DATA_DIR_EX = "datadir_path"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUTO_SCREENSHOT = "s"; //$NON-NLS-1$
    /** object attribute */
    public static final String NO_XML_SCREENSHOT = "sx"; //$NON-NLS-1$

    /** command line option for supplying a workspace location */
    public static final String WORKSPACE = "data"; //$NON-NLS-1$
    /** workspace location argument label */
    public static final String WORKSPACE_ARG = "workspace_location"; //$NON-NLS-1$
    
    
    /** to prevent instantiation */
    private ClientTestStrings() {
        // do nothing
    }
}

==> org.eclipse.jubula.client.core.source_5.0.0.201702201130.jar: org/eclipse/jubula/client/core/businessprocess/ClientTestStrings.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.client.core.businessprocess;

/**
 * @author BREDEX GmbH
 * @created Feb 12, 2007
 */
public class ClientTestStrings {
    /** constant string */
    public static final String PROJECT = "project"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_VERSION = "version"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_VERSION_EX = "project_version"; //$NON-NLS-1$
    /** constant string */
    public static final String PROJECT_NAME = "project_name"; //$NON-NLS-1$
     /** object attribute */
    public static final String SERVER = "server"; //$NON-NLS-1$
    /** constant string */
    public static final String HOSTNAME = "hostname"; //$NON-NLS-1$
    /** object attribute */
    public static final String PORT = "port"; //$NON-NLS-1$
    /** constant string */
    public static final String PORT_NUMBER = "port_number"; //$NON-NLS-1$
    /** object attribute */
    public static final String DBURL = "dburl"; //$NON-NLS-1$
    /** constant string */
    public static final String DATABASE = "database"; //$NON-NLS-1$
    /** object attribute */
    public static final String DB_SCHEME = "dbscheme"; //$NON-NLS-1$
    /** object attribute */
    public static final String SCHEME = "scheme"; //$NON-NLS-1$
    /** object attribute */
    public static final String DB_USER = "dbuser"; //$NON-NLS-1$
    /** constant string */
    public static final String USER = "user"; //$NON-NLS-1$ 
    /** object attribute */
    public static final String DB_PW = "dbpw"; //$NON-NLS-1$
    /** constant string */
    public static final String PASSWORD = "password"; //$NON-NLS-1$
    /** object attribute */
    public static final String TESTSUITE = "testsuite"; //$NON-NLS-1$
    /** object attribute */
    public static final String TESTJOB = "testjob"; //$NON-NLS-1$
    /** object attribute */
    public static final String TIMEOUT = "timeout"; //$NON-NLS-1$
    /** constant string */
    public static final String GENERATE_MONITORING_REPORT = "generate_monitoring_report"; //$NON-NLS-1$
    /** object attribute */
    public static final String ENTRY = "entry"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUT_CONFIG = "autconfig"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUT_ID = "autid"; //$NON-NLS-1$
    /** object attribute */
    public static final String RESULTDIR = "resultdir"; //$NON-NLS-1$
    /** object attribute */
    public static final String DATA_DIR = "datadir"; //$NON-NLS-1$
    /** object attribute */
    public static final String DATA_DIR_EX = "datadir_path"; //$NON-NLS-1$
    /** object attribute */
    public static final String AUTO_SCREENSHOT = "s"; //$NON-NLS-1$
    /** object attribute */
    public static final String ITER_MAX = "itermax"; //$NON-NLS-1$
    /** object attribute */
    public static final String NO_XML_SCREENSHOT = "sx"; //$NON-NLS-1$

    /** command line option for supplying a workspace location */
    public static final String WORKSPACE = "data"; //$NON-NLS-1$
    /** workspace location argument label */
    public static final String WORKSPACE_ARG = "workspace_location"; //$NON-NLS-1$
    
    
    /** to prevent instantiation */
    private ClientTestStrings() {
        // do nothing
    }
}
